#ifndef GUARD_SUDOKU_GRID_H
#define GUARD_SUDOKU_GRID_H
/**************************************************************************
 * This is the start of classes to simplify the business of working with
 * a sudoku setup.
 * ************************************************************************/ 
#include <vector>
#include <string>
/***************************************************************************
 * A coord object stores two integer coordinates.
 ***************************************************************************/
class coords{
	std::vector<int> xy;

	public:
	/* Default constructor */
	coords():xy(std::vector<int>(2,0)){};// note initializer list

	/* Constructor to set two integer coordinates */
	coords(int,int);
	int & operator[](int);
	int operator[](int) const;
	bool operator==(coords) const;
	bool operator!=(coords) const;
};

/*************************************************************************
 * A sudoku_grid object stores the data for a single sudoku game. It has
 * member functions to facilitate solving the game, either interactively
 * or computationally.
 *************************************************************************/
class sudoku_grid{
	//Private, by default
	typedef std::vector<std::vector<std::vector<int> > > grid_config;
	grid_config grid;
	std::vector<int> value_count(coords square) const;
	
	public:
	/* Construct a grid with all possibilities in
	 * each square
	 */
	sudoku_grid();
	
	/* Construct a grid based on the file
	 * whose name is stored in the string.
	 */
	sudoku_grid(std::string);

	/* Display the possibilities in each square
	 * to the screen
	 */
	void display() const;

	/* Set the given value in the given square.
	 * Return true if the set is successful.
	 * Return false if the value wasn't available in
	 * the square, or if the attendant deletions would
	 * cause some square to be empty.
	 */
	bool set(coords square, int value);

	/* Delete the given value from the given square.
	 * Return false if that would empty the square. 
	 * Otherwise return true.
	 * */
	bool del(coords square, int value);
	
	
	
};
#endif





